pub(crate) fn has_expired_transactions(
subblock: &RecoveredSubBlock,
timestamp: u64,
) -> boolExpand description
Returns true if a subblock has any expired transactions for the given timestamp.
pub(crate) fn has_expired_transactions(
subblock: &RecoveredSubBlock,
timestamp: u64,
) -> boolReturns true if a subblock has any expired transactions for the given timestamp.